Class: Nfoiled::Window

Inherits:
Object
  • Object
show all
Defined in:
lib/nfoiled/window.rb

Overview

An Nfoiled::Window is a “box” in the terminal to which output can be printed and from which input can be received. A basic Nfoiled application will utilize only one of these, a single Window covering the entirety of the Terminal‘s available area.

Instance Method Summary collapse

Instance Method Details

#windowsObject

This is simply an accessor for all the windows on the current Terminal.



9
# File 'lib/nfoiled/window.rb', line 9

def windows; Terminal.current ? Terminal.current.windows : nil; end